[CCCL] 瘦身 + 补全: 移除 cudax/python/libcudacxx-tests 冗余文件, 新增 c2h 测试助手 + cmake 构建系统 + 8 个 CUDA thrust examples
变更摘要:
- 删除: cudax/ (783 files, 7.2M) — 实验性组件,竞赛不需要
- 删除: python/ (226 files, 2.0M) — Python 绑定,竞赛不需要
- 删除: libcudacxx/{test,benchmarks,codegen,cmake,share} (4432 files, 31M)
保留: libcudacxx/include/ (1463 headers, cuda::std 编译依赖)
- 新增: c2h/ (27 files) — CUB Catch2 测试辅助头文件,编译 243 个测试必需
- 新增: cmake/ (29 files) — CCCL 原生 CMake 构建系统
- 新增: thrust/examples/cuda/ (7 files) + cpp_integration/ (1 file)
async_reduce, custom_temporary_allocation, explicit_cuda_stream,
global_device_vector, range_view, unwrap_pointer, wrap_pointer, device
结果: cccl_upstream 从 74M→35M (瘦身 53%), 核心内容 100% 保留:
27/27 tuning headers, 78 benchmarks, 243 tests,
60 thrust examples, 18 CUB examples, 全部编译头文件
This commit is contained in:
@@ -1,177 +0,0 @@
|
||||
//===----------------------------------------------------------------------===//
|
||||
//
|
||||
// Part of CUDASTF in CUDA C++ Core Libraries,
|
||||
// under the Apache License v2.0 with LLVM Exceptions.
|
||||
// See https://llvm.org/LICENSE.txt for license information.
|
||||
// SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
|
||||
// SPDX-FileCopyrightText: Copyright (c) 2022-2025 NVIDIA CORPORATION & AFFILIATES.
|
||||
//
|
||||
//===----------------------------------------------------------------------===//
|
||||
|
||||
/**
|
||||
* @file
|
||||
* @brief Test for graph_scope RAII functionality in stackable_ctx
|
||||
*
|
||||
* This test demonstrates and validates the graph_scope RAII wrapper
|
||||
* for automatic push/pop management in nested contexts.
|
||||
*/
|
||||
|
||||
#include <cuda/experimental/stf.cuh>
|
||||
|
||||
using namespace cuda::experimental::stf;
|
||||
|
||||
int main()
|
||||
{
|
||||
stackable_ctx ctx;
|
||||
|
||||
int input[1024];
|
||||
for (size_t i = 0; i < 1024; i++)
|
||||
{
|
||||
input[i] = static_cast<int>(i);
|
||||
}
|
||||
|
||||
auto data = ctx.logical_data(input).set_symbol("data");
|
||||
|
||||
// Test 1: Direct constructor style (lock_guard style) - most idiomatic
|
||||
{
|
||||
stackable_ctx::graph_scope_guard scope{ctx}; // push() called here
|
||||
|
||||
auto temp = ctx.logical_data(data.shape()).set_symbol("temp");
|
||||
|
||||
ctx.parallel_for(temp.shape(), temp.write(), data.read())->*[] __device__(size_t i, auto temp, auto data) {
|
||||
temp(i) = data(i) * 2;
|
||||
};
|
||||
|
||||
ctx.parallel_for(data.shape(), data.write(), temp.read())->*[] __device__(size_t i, auto data, auto temp) {
|
||||
data(i) = temp(i) + 1;
|
||||
};
|
||||
|
||||
// pop() called automatically when scope goes out of scope
|
||||
}
|
||||
|
||||
// Test 2: Factory method style (convenience)
|
||||
{
|
||||
auto scope = ctx.graph_scope(); // push() called here
|
||||
|
||||
auto temp = ctx.logical_data(data.shape()).set_symbol("temp2");
|
||||
|
||||
ctx.parallel_for(temp.shape(), temp.write(), data.read())->*[] __device__(size_t i, auto temp, auto data) {
|
||||
temp(i) = data(i) * 3;
|
||||
};
|
||||
|
||||
ctx.parallel_for(data.shape(), data.write(), temp.read())->*[] __device__(size_t i, auto data, auto temp) {
|
||||
data(i) = temp(i);
|
||||
};
|
||||
|
||||
// pop() called automatically when scope goes out of scope
|
||||
}
|
||||
|
||||
// Test 3: Nested scopes with direct constructor style
|
||||
{
|
||||
stackable_ctx::graph_scope_guard outer_scope{ctx}; // outer push
|
||||
|
||||
auto intermediate = ctx.logical_data(data.shape()).set_symbol("intermediate");
|
||||
|
||||
ctx.parallel_for(intermediate.shape(), intermediate.write(), data.read())
|
||||
->*[] __device__(size_t i, auto inter, auto data) {
|
||||
inter(i) = data(i) / 2;
|
||||
};
|
||||
|
||||
{
|
||||
stackable_ctx::graph_scope_guard inner_scope{ctx}; // inner push (nested)
|
||||
|
||||
auto temp = ctx.logical_data(data.shape()).set_symbol("nested_temp");
|
||||
|
||||
ctx.parallel_for(temp.shape(), temp.write(), intermediate.read())->*[] __device__(size_t i, auto temp, auto inter) {
|
||||
temp(i) = inter(i) + 10;
|
||||
};
|
||||
|
||||
ctx.parallel_for(data.shape(), data.write(), temp.read())->*[] __device__(size_t i, auto data, auto temp) {
|
||||
data(i) = temp(i);
|
||||
};
|
||||
|
||||
// inner pop() called automatically here
|
||||
}
|
||||
|
||||
// outer pop() called automatically here
|
||||
}
|
||||
|
||||
// Test 4: Iterative pattern (like stackable2.cu)
|
||||
for (int iter = 0; iter < 3; iter++)
|
||||
{
|
||||
stackable_ctx::graph_scope_guard iteration{ctx}; // New scope each iteration
|
||||
|
||||
auto temp = ctx.logical_data(data.shape()).set_symbol("iter_temp");
|
||||
|
||||
// tmp = data
|
||||
ctx.parallel_for(temp.shape(), temp.write(), data.read())->*[] __device__(size_t i, auto temp, auto data) {
|
||||
temp(i) = data(i);
|
||||
};
|
||||
|
||||
// data++
|
||||
ctx.parallel_for(data.shape(), data.rw())->*[] __device__(size_t i, auto data) {
|
||||
data(i) += 1;
|
||||
};
|
||||
|
||||
// temp *= 2
|
||||
ctx.parallel_for(temp.shape(), temp.rw())->*[] __device__(size_t i, auto temp) {
|
||||
temp(i) *= 2;
|
||||
};
|
||||
|
||||
// data += temp
|
||||
ctx.parallel_for(data.shape(), temp.read(), data.rw())->*[] __device__(size_t i, auto temp, auto data) {
|
||||
data(i) += temp(i);
|
||||
};
|
||||
|
||||
// pop() called automatically at end of iteration
|
||||
}
|
||||
|
||||
// Test 5: Mixed usage styles
|
||||
{
|
||||
// Outer scope using direct constructor
|
||||
stackable_ctx::graph_scope_guard outer{ctx};
|
||||
|
||||
auto temp1 = ctx.logical_data(data.shape()).set_symbol("temp1");
|
||||
|
||||
{
|
||||
// Inner scope using factory method
|
||||
auto inner = ctx.graph_scope();
|
||||
|
||||
auto temp2 = ctx.logical_data(data.shape()).set_symbol("temp2");
|
||||
|
||||
ctx.parallel_for(temp2.shape(), temp2.write(), data.read())->*[] __device__(size_t i, auto temp2, auto data) {
|
||||
temp2(i) = data(i) + 5;
|
||||
};
|
||||
|
||||
ctx.parallel_for(temp1.shape(), temp1.write(), temp2.read())->*[] __device__(size_t i, auto temp1, auto temp2) {
|
||||
temp1(i) = temp2(i) * 2;
|
||||
};
|
||||
|
||||
// inner pop() automatically
|
||||
}
|
||||
|
||||
ctx.parallel_for(data.shape(), data.write(), temp1.read())->*[] __device__(size_t i, auto data, auto temp1) {
|
||||
data(i) = temp1(i);
|
||||
};
|
||||
|
||||
// outer pop() automatically
|
||||
}
|
||||
|
||||
ctx.finalize();
|
||||
|
||||
for (size_t i = 0; i < 1024; i++)
|
||||
{
|
||||
int expected = static_cast<int>(i);
|
||||
expected = expected * 2 + 1;
|
||||
expected = expected * 3;
|
||||
expected = expected / 2 + 10;
|
||||
for (int iter = 0; iter < 3; iter++)
|
||||
{
|
||||
expected = 3 * expected + 1;
|
||||
}
|
||||
expected = (expected + 5) * 2;
|
||||
EXPECT(input[i] == expected);
|
||||
}
|
||||
|
||||
return 0;
|
||||
}
|
||||
Reference in New Issue
Block a user